@@ -52,8 +52,12 @@ class BaseData(MSONable, abc.ABC):
         Returns:
             An instance of the class.
         """
-        with open(filepath) as f:
-            return cls.from_string(f.read())
+        try:
+            with open(filepath, 'r') as f:
+                return cls.from_string(f.read())
+        except UnicodeDecodeError:
+            with open(filepath, 'r', errors='ignore') as f:
+                return cls.from_string(f.read())
 
     @classmethod
     def from_string(cls, string):
@@ -1418,3 +1422,65 @@ class AoforceVibrationalData(BaseData):
         """
         f_arr = np.array(self.frequencies)
         return np.count_nonzero(np.logical_and(-np.abs(tol) <= f_arr, f_arr <= np.abs(tol)))
+
+
+class MP2Data(BaseData):
+    """
+    MP2 data object containing parameters used to run the MP2 calculation.
+    """
+
+    def __init__(self, energy_only=None):
+        """
+        Args:
+            energy_only (bool): whether this is an energy-only MP2 calculation.
+        """
+        self.energy_only = energy_only
+
+    @classmethod
+    def from_parser(cls, parser):
+        """
+        Generates an instance of MP2Data from a parser based on the stdout
+        of a Turbomole executable. Returns None if no data could be parsed.
+
+        Args:
+            parser (Parser): the parser to be used to extract the data.
+
+        Returns:
+            MP2Data.
+        """
+        data = parser.mp2_data
+        if not data:
+            return None
+
+        return cls(**data)
+
+
+class MP2Results(BaseData):
+    """
+    MP2 results object.
+    """
+
+    def __init__(self, energy=None):
+        """
+        Args:
+            energy (float): MP2 energy.
+        """
+        self.energy = energy
+
+    @classmethod
+    def from_parser(cls, parser):
+        """
+        Generates an instance of MP2Results from a parser based on the stdout
+        of a Turbomole executable. Returns None if no data could be parsed.
+
+        Args:
+            parser (Parser): the parser to be used to extract the data.
+
+        Returns:
+            MP2Results.
+        """
+        data = parser.mp2_results
+        if not data or "energy" not in data:
+            return None
+
+        return cls(**data)
