@@ -36,7 +36,7 @@ date_format = "%Y-%m-%d %H:%M:%S.%f"
 float_number_re = r"[+-]?[0-9]*[.]?[0-9]+"
 float_number_d_re = r"[+-]?[0-9]*[.]?[0-9]+D[+-]\d{2}"
 float_number_e_re = r"[+-]?[0-9]*[.]?[0-9]+E[+-]\d{2}"
-float_number_all_re = r"[+-]?[0-9]*[.]?[0-9]+([ED][+-]\d{2})*"
+float_number_all_re = r"[+-]?[0-9]*[.]?[0-9]+(?:[ED][+-]\d{2})?"
 irrep_re_group = r"\w'\""
 
 
@@ -224,8 +224,12 @@ class Parser:
             an instance of Parser.
         """
 
-        with open(filepath) as f:
-            string = f.read()
+        try:
+            with open(filepath, 'r') as f:
+                string = f.read()
+        except UnicodeDecodeError:
+            with open(filepath, 'r', errors='ignore') as f:
+                string = f.read()
 
         if check_all_done and string.rfind("all done") < 0:
             raise ValueError("The string does not contain data for a completed calculation")
@@ -261,13 +265,17 @@ class Parser:
         # In this case turbomole version and build will be set to None.
         # For example it may be:
         # escf (node001) : TURBOMOLE rev. compiled 1 Jul 2018 at 20:38:15
-        r_version = r"V([\d\.]+)\s+\(([\s\d]+)\)"
+        r_version = r'V([\d\.]+\d)\s+.*'
+        r_build = r'V[\d\.]+\d\s+\((.*)\)'
         match_version = re.search(r_version, match.group(3).strip())
+        match_build = re.search(r_build, match.group(3).strip())
         if match_version:
             tm_version = match_version.group(1).strip()
-            tm_build = match_version.group(2).strip()
         else:
             tm_version = None
+        if match_build:
+            tm_build = match_build.group(1).strip() or None  # When the build info inside the parenthesis is empty
+        else:
             tm_build = None
 
         d = dict(executable=match.group(1),
@@ -1771,7 +1779,7 @@ class Parser:
 
         def get_single_data(line):
             s = line.split()
-            converged = "yes" is s[-3]
+            converged = "yes" == s[-3]
             return {"value": convert_float(s[-2]), "thr": convert_float(s[-1]), "conv": converged}
 
         data = dict(energy_change=None,
@@ -2064,6 +2072,59 @@ class Parser:
 
         return data
 
+    @lazy_property
+    def mp2_data(self):
+        """
+        MP2 data: information of MP2 calculation.
+
+        Returns:
+            dict with "energy_only".
+        """
+
+        # TODO: implement or mpgrad and rimp2/ricc2
+
+        return None
+
+    @lazy_property
+    def mp2_results(self):
+        """
+        MP2 results.
+
+        Returns:
+            dict with "energy".
+        """
+
+        energy = None
+        # Try to parse from rimp2/ricc2 programs
+        r = r"\*{62,62}\s+\*\s+\*\s+\*<{10,10}\s+"
+        r += r"GROUND\s+STATE\s+FIRST-ORDER\s+PROPERTIES"
+        r += r"\s+>{11,11}\*\s+\*\s+\*\s+\*{62,62}\s+"
+        r += r"-{48,48}\s+Method\s+:\s+MP2\s+Total\s+Energy\s+:\s+("
+        r += float_number_all_re
+        r += r")\s+"
+        m = re.findall(r, string=self.string)
+        if len(m) == 1:
+            energy = convert_float(m[0])
+        elif len(m) > 1:
+            raise RuntimeError("Error parsing the MP2 results. Multiple occurrences of MP2 results found.")
+
+        # Try to parse from mpgrad program
+        r = r"\*{53,53}\s+\*\s+\*\s+\*\s+"
+        r += r"SCF-energy\s+:\s+(" + float_number_all_re + r")\s+\*\s+\*\s+"
+        r += r"MP2-energy\s+:\s+(" + float_number_all_re + r")\s+\*\s+\*\s+"
+        r += r"total\s+:\s+(" + float_number_all_re + r")\s+\*\s+\*\s+"
+        r += r"\*\s+\*\s+\(MP2-energy\s+evaluated\s+from\s+T2\s+amplitudes\)\s+\*\s+\*\s+\*\s+\*{53,53}"
+        m = re.findall(r, string=self.string)
+        if len(m) == 1:
+            if energy is not None:
+                raise RuntimeError("Error parsing the MP2 results. "
+                                   "Found MP2 results from both mpgrad- and rimp2/ricc2-like calculations.")
+            energy = convert_float(m[0][2])
+        elif len(m) > 1:
+            raise RuntimeError("Error parsing the MP2 results. Multiple occurrences of MP2 results found.")
+
+        return dict(energy=energy)
+
     def get_split_jobex_parsers(self):
         """
         Given the string of the "job.last" output file of jobex generates the
